==> bitcoin_0.12.1.orig.tar.gz: bitcoin-0.12.1/src/qt/locale/bitcoin_tr_TR.ts <==
<TS language="tr_TR" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>Adresi veya etiketi düzenlemek için sağ tıklayın</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Yeni adres oluştur</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Yeni</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Seçili adresi panoya kopyala</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopyala</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>K&amp;apat</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Adresi Kopyala</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Seçili adresi listeden sil</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Seçili sekmedeki veriyi dosya olarak dışa aktar</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Dışa Aktar</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Sil</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Para göndereceğiniz adresi seçin</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Parayı alacağınız adresi seçin</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>S&amp;eç</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Gönderim adresleri</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Alış adresleri</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Bunlar ödeme gönderebileceğiniz Bitcoin adreslerinizdir. Para göndermeden önce mutlaka alıcı adresini ve tutarı kontrol edin.</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
        <translation>Bunlar ödeme alabileceğiniz Bitcoin adreslerinizdir. Her işlem için yeni bir adres kullanmanız önerilir.</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopyala &amp;Etiketle</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Düzenle</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Adres Listesini Dışa Aktar</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Dışa Aktarma Başarısız Oldu</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Adres listesini %1'e kaydederken bir hata oluştu. Lütfen tekrar deneyin.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etiket</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(etiket yok)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Receiving addresses...</source>
        <translation>Alış adresleri</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>(no label)</source>
        <translation>(etiket yok)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Label</source>
        <translation>Etiket</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>Adres</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Copy &amp;Address</source>
        <translation>&amp;Adresi Kopyala</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiket</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etiket</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(etiket yok)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>(no label)</source>
        <translation>(etiket yok)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etiket</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Exporting Failed</source>
        <translation>Dışa Aktarma Başarısız Oldu</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiket</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Dışa Aktar</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Seçili sekmedeki veriyi dosya olarak dışa aktar</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>

==> bitcoin_0.13.1.orig.tar.gz: bitcoin-0.13.1/src/qt/locale/bitcoin_tr_TR.ts <==
<TS language="tr_TR" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>Adresi veya etiketi düzenlemek için sağ tıklayın</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Yeni adres oluştur</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Yeni</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Seçili adresi panoya kopyala</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopyala</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>K&amp;apat</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Seçili adresi listeden sil</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Seçili sekmedeki veriyi dosya olarak dışa aktar</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Dışa Aktar</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Sil</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Receiving addresses...</source>
        <translation>Alış adresleri</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Label</source>
        <translation>Etiket</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>Adres</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Copy &amp;Address</source>
        <translation>&amp;Adresi Kopyala</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    </context>
<context>
    <name>SendCoinsDialog</name>
    </context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    </context>
<context>
    <name>TransactionView</name>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>
